@@ -7,16 +7,13 @@ import click
 import yaml
 
 import datetime
-import argparse
 import json
 
 import MAIA
-import os
-import subprocess
 from argparse import ArgumentParser, RawTextHelpFormatter
 from pathlib import Path
 from textwrap import dedent
-
+from MAIA.maia_fn import convert_username_to_jupyterhub_username
 version = MAIA.__version__
 
 TIMESTAMP = "{:%Y-%m-%d_%H-%M-%S}".format(datetime.datetime.now())
@@ -99,7 +96,7 @@ def create_maia_addons_config_api( form,
     oauth_url = user_form["oauth_url"]
 
     for user in users:
-        jupyterhub_users.append(user.replace("-", "-2d").replace("@", "-40").replace(".", "-2e"))
+        jupyterhub_users.append(convert_username_to_jupyterhub_username(user))
 
     domain = cluster_config["domain"]
 
@@ -194,12 +191,13 @@ def create_maia_addons_config_api( form,
 
     if config_folder is None:
         config_folder = "."
-
-    Path(config_folder).joinpath(namespace).mkdir(parents=True, exist_ok=True)
-    with open(Path(config_folder).joinpath(namespace,f"{namespace}_maia_addons.tf.json"), "w") as f:
+    
+    group_id = user_form["group_ID"]
+    Path(config_folder).joinpath(user_form["group_ID"]).mkdir(parents=True, exist_ok=True)
+    with open(Path(config_folder).joinpath(user_form["group_ID"],f"{group_id}_maia_addons.tf.json"), "w") as f:
         json.dump(maia_addons_template, f, indent=2)
 
-    with open(Path(config_folder).joinpath(namespace,f"{namespace}_maia_addons_values.yaml"), "w") as f:
+    with open(Path(config_folder).joinpath(user_form["group_ID"],f"{group_id}_maia_addons_values.yaml"), "w") as f:
         print(maia_addons_template["resource"]["helm_release"]["maia-addons"]["values"][0], file=f)
 
     helm_namespace = maia_addons_template["resource"]["helm_release"]["maia-addons"]["namespace"]
@@ -208,7 +206,7 @@ def create_maia_addons_config_api( form,
     helm_repo = maia_addons_template["resource"]["helm_release"]["maia-addons"]["repository"]
     helm_repo_version = maia_addons_template["resource"]["helm_release"]["maia-addons"]["version"]
 
-    config_path = Path(config_folder).joinpath(namespace,f"{namespace}_maia_addons_values.yaml")
+    config_path = Path(config_folder).joinpath(user_form["group_ID"],f"{group_id}_maia_addons_values.yaml")
     cmds =[
         # "Run the following command to deploy JupyterHub: ",
         f"helm repo add maia {helm_repo}",
